@@ -1,4 +1,3 @@
-/* $Id: xfburn-audio-track-gst.h 7503 2009-06-08 05:35:32Z squisher $ */
 /*
  *  Copyright (c) 2008      David Mohr (david@mcbf.net)
  *
@@ -39,7 +38,7 @@ typedef struct {
   off_t size;
 } XfburnAudioTrackGst;
 
-GType xfburn_audio_track_gst_get_type ();
+GType xfburn_audio_track_gst_get_type (void);
 
 G_END_DECLS
 
