@@ -118,7 +118,7 @@ xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBa
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
-  
+
   object_class->finalize = xfburn_burn_data_composition_base_dialog_finalize;
   object_class->get_property = xfburn_burn_data_composition_base_dialog_get_property;
   object_class->set_property = xfburn_burn_data_composition_base_dialog_set_property;
@@ -134,27 +134,20 @@ static void
 xfburn_burn_data_composition_base_dialog_init(XfburnBurnDataCompositionBaseDialog *obj)
 {
   XfburnBurnDataCompositionBaseDialogPrivate *priv = xfburn_burn_data_composition_base_dialog_get_instance_private(obj);
-  GdkPixbuf *icon = NULL;
   GtkBox *box;
   GtkWidget *img;
   GtkWidget *frame;
   GtkWidget *vbox;
-  GtkWidget *align;
   GtkWidget *button;
   gchar *default_path;
   gchar *tmp_dir;
   const char *comp_name;
-  gint x,y;
 
   box = GTK_BOX (gtk_dialog_get_content_area((GTK_DIALOG (obj))));
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn Composition"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
-  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
-
-  gtk_window_set_icon (GTK_WINDOW (obj), icon);
-  g_object_unref (icon);
+  gtk_window_set_icon_name (GTK_WINDOW (obj), "stock_xfburn");
 
   /* burning devices list */
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_MODE_SELECTION | SHOW_SPEED_SELECTION);
@@ -315,7 +308,7 @@ xfburn_burn_data_composition_base_dialog_finalize (GObject * object)
   XfburnBurnDataCompositionBaseDialogPrivate *priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (object);
 
   iso_image_unref (priv->image);
-  
+
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -347,7 +340,7 @@ create_proceed_button (XfburnBurnDataCompositionBaseDialog * dialog, const gchar
   return button;
 }
 
-void 
+void
 update_proceed_button (XfburnBurnDataCompositionBaseDialog * dialog)
 {
   XfburnBurnDataCompositionBaseDialogPrivate *priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (dialog);
@@ -365,7 +358,7 @@ cb_check_only_iso_toggled (GtkToggleButton * button, XfburnBurnDataCompositionBa
 
   gtk_widget_set_sensitive (priv->frame_device, !gtk_toggle_button_get_active (button));
   xfburn_device_box_set_sensitive (XFBURN_DEVICE_BOX (priv->device_box), !gtk_toggle_button_get_active (button));
-  
+
   gtk_widget_set_sensitive (priv->hbox_iso, gtk_toggle_button_get_active (button));
   gtk_widget_set_sensitive (priv->check_eject, !gtk_toggle_button_get_active (button));
   gtk_widget_set_sensitive (priv->check_burnfree, !gtk_toggle_button_get_active (button));
@@ -391,7 +384,7 @@ static void
 cb_browse_iso (GtkButton * button, XfburnBurnDataCompositionBaseDialog * dialog)
 {
   XfburnBurnDataCompositionBaseDialogPrivate *priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (dialog);
-  
+
   xfburn_browse_for_file (GTK_ENTRY (priv->entry_path_iso), GTK_WINDOW (dialog));
 }
 
@@ -459,13 +452,13 @@ thread_write_iso (ThreadWriteIsoParams * params)
   /* FIXME: is size really always 2048? */
   while (read_fn (params->src, buf, 2048) == 2048) {
     if (write (fd, buf, 2048) < 2048) {
-      /* an error occured while writing */
+      /* an error occurred while writing */
       gchar err[256];
       gchar *error_msg = NULL;
-      
+
       strerror_r (errno, err, 256);
-    
-      error_msg = g_strdup_printf (_("An error occured while writing ISO: %s"), err);
+
+      error_msg = g_strdup_printf (_("An error occurred while writing ISO: %s"), err);
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), error_msg);
       g_free (error_msg);
       goto cleanup;
@@ -507,7 +500,7 @@ typedef struct {
   gboolean stream_recording;
 } ThreadBurnCompositionParams;
 
-static void 
+static void
 thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_drive *drive,
                            struct burn_disc *disc, struct burn_session *session, struct burn_track *track)
 {
@@ -530,7 +523,7 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
     xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend."));
     return;
   }
-  
+
   burn_session_add_track (session, track, BURN_POS_END);
 
   burn_options = burn_write_opts_new (drive);
@@ -643,7 +636,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
     dialog_progress = xfburn_progress_dialog_new (GTK_WINDOW (dialog));
     gtk_window_set_transient_for (GTK_WINDOW (dialog_progress), gtk_window_get_transient_for (GTK_WINDOW (dialog)));
     gtk_widget_hide (GTK_WIDGET (dialog));
-    
+
     gtk_widget_show (dialog_progress);
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_only_iso))) {
@@ -694,6 +687,6 @@ xfburn_burn_data_composition_base_dialog_new (IsoImage *image)
   XfburnBurnDataCompositionBaseDialog *obj;
 
   obj = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG (g_object_new (XFBURN_TYPE_BURN_DATA_COMPOSITION_BASE_DIALOG, "image", image, NULL));
-  
+
   return GTK_WIDGET (obj);
 }
