@@ -145,8 +145,10 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_file_filter_add_pattern (filter, "*");
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(priv->chooser_image), filter);
   filter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filter, _("ISO images"));
+  gtk_file_filter_set_name (filter, _("Disc images"));
   gtk_file_filter_add_pattern (filter, "*.[iI][sS][oO]");
+  gtk_file_filter_add_pattern (filter, "*.[iI][mM][gG]");
+  gtk_file_filter_add_pattern (filter, "*.[tT][oO][aA][sS][tT]");
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
   gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
 
