@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef	HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif /* !HAVE_CONFIG_H */
 
@@ -118,7 +118,6 @@ static void action_remove_selection (GSimpleAction *, GVariant *, XfburnDataComp
 static void action_rename_selection (GSimpleAction *, GVariant *, XfburnDataComposition *);
 static void action_add_or_select (GSimpleAction *, GVariant *, XfburnDataComposition *);
 static void add_files (gchar * files, XfburnDataComposition *);
-static void add_cb (GtkWidget * widget, gpointer data);
 
 static gboolean cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, XfburnDataComposition * dc);
 static void cb_treeview_row_activated (GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * column, XfburnDataComposition * composition);
@@ -131,6 +130,7 @@ static void cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, g
 static void cb_content_drag_data_get (GtkWidget * widget, GdkDragContext * dc, GtkSelectionData * data, guint info,
                                       guint timestamp, XfburnDataComposition * content);
 static void cb_adding_done (XfburnAddingProgress *progress, XfburnDataComposition *dc);
+static void cb_key_press_event (GtkWidget * widget, GdkEvent * event, XfburnDataComposition * composition);
 
 /* thread entry points */
 static gpointer thread_add_files_cli (ThreadAddFilesCLIParams *params);
@@ -195,28 +195,6 @@ static const GActionEntry action_entries[] = {
   /*{.name = "import-session", .activate = (gActionCallback)action_remove_selection},*/
   {.name = "rename-file", .activate = (gActionCallback)action_rename_selection},
 };
-/*
-static const GtkActionEntry action_entries[] = {
-  {"add-file", "list-add", N_("Add"), NULL, N_("Add the selected file(s) to the composition"),
-   G_CALLBACK (action_add_or_select),},
-  {"create-dir", "document-new", N_("Create directory"), NULL, N_("Add a new directory to the composition"),
-   G_CALLBACK (action_create_directory),},
-  {"remove-file", "list-remove", N_("Remove"), NULL, N_("Remove the selected file(s) from the composition"),
-   G_CALLBACK (action_remove_selection),},
-  {"clear", "edit-clear", N_("Clear"), NULL, N_("Clear the content of the composition"),
-   G_CALLBACK (action_clear),},
-  /*{"import-session", "xfburn-import-session", N_("Import"), NULL, N_("Import existing session"),}, */
-/*  {"rename-file", "gtk-edit", N_("Rename"), NULL, N_("Rename the selected file"),
-   G_CALLBACK (action_rename_selection),},
-};*/
-
-static const gchar *toolbar_actions[] = {
-  "add-file",
-  "remove-file",
-  "create-dir",
-  "clear",
-  "import-session",
-};
 
 static GdkPixbuf *icon_directory = NULL, *icon_file = NULL;
 
@@ -257,11 +235,8 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
 {
   XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (composition);
 
-  gtk_orientable_set_orientation(GTK_ORIENTABLE (composition), GTK_ORIENTATION_VERTICAL);
-
   gint x, y;
-//  ExoToolbarsModel *model_toolbar;
-  gint toolbar_position;
+  gchar *popup_ui;
   GtkWidget *hbox_toolbar;
   GtkWidget *hbox, *label;
   GtkWidget *scrolled_window;
@@ -279,6 +254,8 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
                                 { "text/plain;charset=utf-8", 0, DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN },
                               };
 
+  gtk_orientable_set_orientation(GTK_ORIENTABLE (composition), GTK_ORIENTATION_VERTICAL);
+
   priv->full_paths_to_add = NULL;
 
   instances++;
@@ -302,7 +279,7 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
   gtk_builder_set_translation_domain(priv->ui_manager, GETTEXT_PACKAGE);
 
   xfce_resource_push_path (XFCE_RESOURCE_DATA, DATADIR);
-  gchar *popup_ui = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-popup-menus.ui");
+  popup_ui = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-popup-menus.ui");
   gtk_builder_add_from_file (priv->ui_manager, popup_ui, NULL);
 
   hbox_toolbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
@@ -444,6 +421,10 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
 
   action = g_action_map_lookup_action (G_ACTION_MAP (priv->action_group), "remove-file");
   g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
+
+  /* map delete key to remove file action */
+  g_signal_connect (G_OBJECT (priv->content), "key-press-event", G_CALLBACK (cb_key_press_event),
+                    composition);
 }
 
 static void
@@ -570,25 +551,20 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
 
   if ((event->button == 3) && (event->type == GDK_BUTTON_PRESS)) {
     GtkTreeSelection *selection;
-    GtkTreePath *path;
     GMenuModel *model;
     GtkWidget *menu_popup;
     GtkWidget *menuitem_remove;
     GtkWidget *menuitem_rename;
+    GList *childs;
+    GdkRectangle r = {event->x, event->y, 1, 1};
 
     selection = gtk_tree_view_get_selection (treeview);
 
-    if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL)) {
-      gtk_tree_selection_unselect_all (selection);
-      gtk_tree_selection_select_path (selection, path);
-      gtk_tree_path_free (path);
-    }
-
     model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "data-popup-menu"));
     menu_popup = gtk_menu_new_from_model (model);
     gtk_widget_insert_action_group(GTK_WIDGET(menu_popup), "win", G_ACTION_GROUP(priv->action_group));
 
-    GList *childs = gtk_container_get_children (GTK_CONTAINER (menu_popup));
+    childs = gtk_container_get_children (GTK_CONTAINER (menu_popup));
     menuitem_remove = GTK_WIDGET (childs->next->next->data);
     menuitem_rename = GTK_WIDGET (childs->next->data);
 
@@ -601,7 +577,6 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
     else
       gtk_widget_set_sensitive (menuitem_rename, FALSE);
 
-    GdkRectangle r = {event->x, event->y, 1, 1};
     gtk_menu_popup_at_rect (GTK_MENU (menu_popup),
         gtk_widget_get_parent_window (GTK_WIDGET (treeview)),
         &r, GDK_GRAVITY_SOUTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
@@ -724,6 +699,24 @@ cb_adding_done (XfburnAddingProgress *progress, XfburnDataComposition *dc)
   xfburn_default_cursor (priv->content);
 }
 
+/**
+ * Handle the key-press-event on the data composition interface.
+ *
+ * If the delete key was pressed, remove the currently-selected item.
+ */
+static void
+cb_key_press_event (GtkWidget *widget, GdkEvent *event, XfburnDataComposition *composition)
+{
+  XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (composition);
+  guint keyval;
+
+  gdk_event_get_keyval (event, &keyval);
+
+  if (keyval == GDK_KEY_Delete) {
+    g_action_group_activate_action (G_ACTION_GROUP (priv->action_group), "remove-file", NULL);
+  }
+}
+
 static void
 action_rename_selection (GSimpleAction *action, GVariant *param, XfburnDataComposition *dc)
 {
@@ -902,83 +895,6 @@ action_remove_selection (GSimpleAction *action, GVariant *param, XfburnDataCompo
   g_list_free (references);
 }
 
-static void
-add_cb (GtkWidget * widget, gpointer data)
-{
-    XfburnDataComposition * dc = XFBURN_DATA_COMPOSITION(data);
-    XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (dc);
-    gchar *selected_files = NULL;
-
-    GSList *list = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (priv->add_filechooser));
-    GString  * str = g_string_new(NULL);
-    GSList * curr;
-
-    priv->last_directory = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER(priv->add_filechooser));
-
-    for (curr = list; curr!=NULL; curr = curr->next) {
-        g_string_append(str, curr->data);
-        g_string_append_c(str, '\n');;
-    }
-
-    g_slist_free_full (list, g_free);
-    selected_files = str->str;
-    g_string_free (str, FALSE);
-    DBG("selected  files: %s ", selected_files);
-
-    gtk_widget_destroy (priv->add_window);
-
-    add_files (selected_files, dc);
-}
-
-static void
-select_files (XfburnDataComposition * dc)
-{
-    XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (dc);
-
-    GtkWidget * window;
-    GtkWidget * add_button;
-    GtkWidget * vbox;
-    GtkWidget * bbox;
-
-    priv->add_window = window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_DIALOG);
-    gtk_window_set_title (GTK_WINDOW(window), _("File(s) to add to composition"));
-    gtk_window_set_position (GTK_WINDOW(window), GTK_WIN_POS_CENTER); // GTK_WINDOW(xfburn_main_window_get_instance()),
-    gtk_container_set_border_width (GTK_CONTAINER(window), 10);
-    gtk_window_set_default_size(GTK_WINDOW(window), 600, 400);
-
-    priv->add_filechooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_OPEN);
-
-    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(priv->add_filechooser), TRUE);
-
-    if(xfburn_main_has_initial_dir ()) {
-      gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(priv->add_filechooser), xfburn_main_get_initial_dir ());
-    }
-
-    if (priv->last_directory)
-      gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(priv->add_filechooser), priv->last_directory);
-
-    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_container_add(GTK_CONTAINER(window), vbox);
-
-    gtk_box_pack_start(GTK_BOX(vbox), priv->add_filechooser, TRUE, TRUE, 3);
-
-    add_button = gtk_button_new_with_label (_("Add"));
-    g_signal_connect (add_button, "clicked", G_CALLBACK(add_cb), dc);
-    g_signal_connect (priv->add_filechooser, "file-activated", G_CALLBACK(add_cb), dc);
-
-    bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-    gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
-    gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 3);
-
-    gtk_box_pack_end(GTK_BOX(bbox), add_button, FALSE, FALSE, 3);
-
-    g_signal_connect(window, "destroy",
-                     G_CALLBACK(gtk_widget_destroyed), &window);
-
-    gtk_widget_show_all (window);
-}
-
 static void
 action_add_or_select (GSimpleAction *action, GVariant *param, XfburnDataComposition *dc)
 {
@@ -987,7 +903,7 @@ action_add_or_select (GSimpleAction *action, GVariant *param, XfburnDataComposit
 
     add_files (xfburn_file_browser_get_selection (browser), dc);
   } else {
-    select_files(dc);
+    add_files (xfburn_browse_for_files (TRUE), dc);
   }
 }
 
@@ -1544,7 +1460,7 @@ copy_entry_to (XfburnDataComposition *dc, GtkTreeIter *src, GtkTreeIter *dest, G
       }
 
       if (file_exists_on_same_level (model, path_level, FALSE, name)) {
-	xfce_dialog_show_warning(NULL, NULL, _("A file named \"%s\" already exists in this directory, the file hasn't been added."), name);
+        xfce_dialog_show_warning(NULL, NULL, _("A file named \"%s\" already exists in this directory, the file hasn't been added."), name);
         goto cleanup;
       }
 
@@ -1620,9 +1536,9 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
 
     xfburn_adding_progress_show (XFBURN_ADDING_PROGRESS (priv->progress));
 
-    row = selected_rows = *((GList **) gtk_selection_data_get_data(sd));
+    row = selected_rows = *((GList **) (gpointer) gtk_selection_data_get_data(sd));
 
-    if (path_where_insert) {      
+    if (path_where_insert) {
       gtk_tree_model_get_iter (model, &iter_where_insert, path_where_insert);
       iter = &iter_where_insert;
 
@@ -1665,6 +1581,10 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
           continue;
       }
 
+      gtk_tree_model_get_iter (model, &iter_src, path_src);
+      gtk_tree_model_get (model, &iter_src, DATA_COMPOSITION_COLUMN_TYPE, &type,
+                          DATA_COMPOSITION_COLUMN_SIZE, &size, -1);
+
       if (path_where_insert && type == DATA_COMPOSITION_TYPE_DIRECTORY
           && gtk_tree_path_is_descendant (path_where_insert, path_src)) {
 
@@ -1676,10 +1596,6 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
         return;
       }
 
-      gtk_tree_model_get_iter (model, &iter_src, path_src);
-      gtk_tree_model_get (model, &iter_src, DATA_COMPOSITION_COLUMN_TYPE, &type,
-                          DATA_COMPOSITION_COLUMN_SIZE, &size, -1);
-
       /* copy entry */
       if (copy_entry_to (composition, &iter_src, iter, position)) {
         GtkTreePath *path_parent = gtk_tree_path_copy (path_src);
@@ -1699,7 +1615,7 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
           g_free (parent_humansize);
         }
 
-        if (gdk_drag_context_get_actions(dc) == GDK_ACTION_MOVE) {       
+        if (gdk_drag_context_get_actions(dc) == GDK_ACTION_MOVE) {
           /* remove source entry */
           if (gtk_tree_path_up (path_parent) && path_where_insert &&
               !gtk_tree_path_is_descendant (path_where_insert, path_parent)) {
@@ -1812,14 +1728,17 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
     if (G_LIKELY (vfs_paths != NULL)) {
       ThreadAddFilesDragParams *params;
       priv->full_paths_to_add = NULL;
+
+      xfburn_adding_progress_show (XFBURN_ADDING_PROGRESS (priv->progress));
+
       for (vfs_path = vfs_paths; vfs_path != NULL; vfs_path = g_list_next (vfs_path)) {
-	GFile *path = vfs_path->data;
-	if (path == NULL)
+        GFile *path = vfs_path->data;
+        if (path == NULL)
           continue;
-	/* unable to handle non-local files */
-	if (G_UNLIKELY (!g_file_has_uri_scheme (path, "file"))) {
+        /* unable to handle non-local files */
+        if (G_UNLIKELY (!g_file_has_uri_scheme (path, "file"))) {
             g_object_unref (path);
-	    continue;
+            continue;
         }
         full_path = g_file_get_path (path);
         /* if there is no local path, use the URI (which always works) */
@@ -1914,88 +1833,88 @@ static void
 fill_image_with_composition (GtkTreeModel *model, IsoImage *image, IsoDir * parent, GtkTreeIter *iter, GSList **errors)
 {
   do {
-      DataCompositionEntryType type;
-      gchar *name = NULL;
-      gchar *src = NULL;
-      IsoNode *node = NULL;
-      IsoDir *dir = NULL;
-      int r;
-      gchar *basename;
+    DataCompositionEntryType type;
+    gchar *name = NULL;
+    gchar *src = NULL;
+    IsoNode *node = NULL;
+    IsoDir *dir = NULL;
+    int r;
+    gchar *basename;
 
-      gtk_tree_model_get (model, iter, DATA_COMPOSITION_COLUMN_TYPE, &type,
-			  DATA_COMPOSITION_COLUMN_CONTENT, &name, DATA_COMPOSITION_COLUMN_PATH, &src, -1);
+    gtk_tree_model_get (model, iter, DATA_COMPOSITION_COLUMN_TYPE, &type,
+                        DATA_COMPOSITION_COLUMN_CONTENT, &name, DATA_COMPOSITION_COLUMN_PATH, &src, -1);
 
-      if (type == DATA_COMPOSITION_TYPE_DIRECTORY && src == NULL) {
-        /* a directory which the user added for this composition */
-        r = iso_tree_add_new_dir (parent, name, &dir);
-        node = (IsoNode *) dir;
+    if (type == DATA_COMPOSITION_TYPE_DIRECTORY && src == NULL) {
+      /* a directory which the user added for this composition */
+      r = iso_tree_add_new_dir (parent, name, &dir);
+      node = (IsoNode *) dir;
 
-        /* if the new directory is part of the root of the iso,
-         * then its owner will be set to root:root. Not sure what a better
-         * default could be, so I'll just leave it like that. */
-      } else {
-        /* something existing on the filesystem, creating a node
-         * will copy its attributes */
-        r = iso_tree_add_node (image, parent, src, &node);
-      }
+      /* if the new directory is part of the root of the iso,
+        * then its owner will be set to root:root. Not sure what a better
+        * default could be, so I'll just leave it like that. */
+    } else {
+      /* something existing on the filesystem, creating a node
+        * will copy its attributes */
+      r = iso_tree_add_node (image, parent, src, &node);
+    }
 
-      if (r < 0) {
-        char * msg;
+    if (r < 0) {
+      char * msg;
 
-        if (r == ISO_NULL_POINTER)
-          g_error (_("%s: null pointer"), src);
-        else if (r == ISO_OUT_OF_MEM)
-          g_error (_("%s: out of memory"), src);
-        else if (r == ISO_NODE_NAME_NOT_UNIQUE)
-          msg = g_strdup_printf (_("%s: node name not unique"), src);
-        else
-          msg = g_strdup_printf (_("%s: %s (code %X)"), src, iso_error_to_msg(r), r);
+      if ((guint) r == ISO_NULL_POINTER)
+        g_error (_("%s: null pointer"), src);
+      else if ((guint) r == ISO_OUT_OF_MEM)
+        g_error (_("%s: out of memory"), src);
+      else if ((guint) r == ISO_NODE_NAME_NOT_UNIQUE)
+        msg = g_strdup_printf (_("%s: node name not unique"), src);
+      else
+        msg = g_strdup_printf (_("%s: %s (code %X)"), src, iso_error_to_msg(r), r);
 
-        g_warning ("%s", msg);
-        *errors = g_slist_prepend (*errors, msg);
-
-        g_free (name);
-        g_free (src);
-        continue;
-      }
-
-      if (src != NULL && *src != '\0') {
-        basename = g_path_get_basename (src);
-
-        /* check if the file has been renamed */
-        if (strcmp (basename, name) != 0) {
-          /* rename the iso_node */
-          r = iso_node_set_name (node, name);
-
-          if (r == 0) {
-            /* The first string is the renamed name, the second one the original name */
-            xfce_dialog_show_warning(NULL, NULL, _("Duplicate filename '%s' for '%s'"), name, src);
-
-            g_free (basename);
-            g_free (name);
-            g_free (src);
-
-            continue;
-          }
-        }
-
-        g_free (basename);
-      }
+      g_warning ("%s", msg);
+      *errors = g_slist_prepend (*errors, msg);
 
       g_free (name);
       g_free (src);
+      continue;
+    }
 
-      if (type == DATA_COMPOSITION_TYPE_DIRECTORY && gtk_tree_model_iter_has_child (model, iter)) {
-	GtkTreeIter child;
+    if (src != NULL && *src != '\0') {
+      basename = g_path_get_basename (src);
 
-        if (iso_node_get_type(node) != LIBISO_DIR)
-            g_error ("Expected %s to be a directory, but it isn't...\n", src);
+      /* check if the file has been renamed */
+      if (strcmp (basename, name) != 0) {
+        /* rename the iso_node */
+        r = iso_node_set_name (node, name);
 
-        dir = (IsoDir *)node;
+        if (r == 0) {
+          /* The first string is the renamed name, the second one the original name */
+          xfce_dialog_show_warning(NULL, NULL, _("Duplicate filename '%s' for '%s'"), name, src);
 
-	gtk_tree_model_iter_children (model, &child, iter);
-	fill_image_with_composition (model, image, dir, &child, errors);
+          g_free (basename);
+          g_free (name);
+          g_free (src);
+
+          continue;
+        }
       }
+
+      g_free (basename);
+    }
+
+    g_free (name);
+    g_free (src);
+
+    if (type == DATA_COMPOSITION_TYPE_DIRECTORY && gtk_tree_model_iter_has_child (model, iter)) {
+      GtkTreeIter child;
+
+      if (iso_node_get_type(node) != LIBISO_DIR)
+        g_error ("Expected %s to be a directory, but it isn't...\n", src);
+
+      dir = (IsoDir *)node;
+
+      gtk_tree_model_iter_children (model, &child, iter);
+      fill_image_with_composition (model, image, dir, &child, errors);
+    }
   } while (gtk_tree_model_iter_next (model, iter));
 }
 
@@ -2034,7 +1953,7 @@ generate_iso_image (XfburnDataComposition * dc)
 
       g_slist_foreach (errors, (GFunc) concat_free, &combined_msg);
 
-      title = _("Error(s) occured while adding files");
+      title = _("Error(s) occurred while adding files");
       dialog = gtk_dialog_new_with_buttons (title,
                                             GTK_WINDOW (mainwin),
                                             GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -2047,7 +1966,7 @@ generate_iso_image (XfburnDataComposition * dc)
       gtk_label_set_markup(GTK_LABEL (label), title);
       g_free (title);
 
-	  gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
+      gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
 
       textview = gtk_text_view_new ();
       buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
@@ -2100,6 +2019,7 @@ _find_attribute (const gchar ** attribute_names, const gchar * attr)
 }
 */
 
+G_GNUC_NORETURN
 static void
 load_composition_start (GMarkupParseContext * context, const gchar * element_name,
                         const gchar ** attribute_names, const gchar ** attribute_values,
@@ -2371,4 +2291,3 @@ xfburn_data_composition_show_toolbar (XfburnDataComposition * composition)
 
   gtk_widget_show (priv->toolbar);
 }
-
