@@ -6,12 +6,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -67,11 +67,11 @@ typedef struct
   gboolean show_mode_selection;
   gboolean valid_disc;
   gboolean blank_mode;
-  
+
 
   GtkWidget *hbox_refresh;
   GtkWidget *disc_label;
-  
+
   GtkWidget *hbox_speed_selection;
   GtkWidget *combo_speed;
 
@@ -86,11 +86,12 @@ typedef struct
 
   gulong handler_volume_change_start;
   gulong handler_volume_change_end;
-  
+
   XfburnDeviceList *devlist;
 } XfburnDeviceBoxPrivate;
 
 /* prototypes */
+static GObject * xfburn_device_box_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties);
 static void xfburn_device_box_finalize (GObject * object);
 static void xfburn_device_box_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void xfburn_device_box_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
@@ -124,40 +125,50 @@ static void
 xfburn_device_box_class_init (XfburnDeviceBoxClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  
+
   parent_class = g_type_class_peek_parent (klass);
-  
+
+  object_class->constructor  = xfburn_device_box_constructor;
   object_class->finalize     = xfburn_device_box_finalize;
   object_class->set_property = xfburn_device_box_set_property;
   object_class->get_property = xfburn_device_box_get_property;
-  
+
   signals[VOLUME_CHANGED] = g_signal_new ("volume_changed", XFBURN_TYPE_DEVICE_BOX, G_SIGNAL_ACTION,
                                           G_STRUCT_OFFSET (XfburnDeviceBoxClass, volume_changed),
                                           NULL, NULL, xfburn_cclosure_marshal_VOID__BOOLEAN_OBJECT,
                                           G_TYPE_NONE, 2, G_TYPE_BOOLEAN, XFBURN_TYPE_DEVICE);
-    
-  g_object_class_install_property (object_class, PROP_SHOW_WRITERS_ONLY, 
+
+  g_object_class_install_property (object_class, PROP_SHOW_WRITERS_ONLY,
                                    g_param_spec_boolean ("show-writers-only", _("Show writers only"),
                                                         _("Show writers only"),
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-  g_object_class_install_property (object_class, PROP_SHOW_SPEED_SELECTION, 
+  g_object_class_install_property (object_class, PROP_SHOW_SPEED_SELECTION,
                                    g_param_spec_boolean ("show-speed-selection", _("Show speed selection"),
-                                                        _("Show speed selection combo"), 
+                                                        _("Show speed selection combo"),
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-  g_object_class_install_property (object_class, PROP_SHOW_MODE_SELECTION, 
+  g_object_class_install_property (object_class, PROP_SHOW_MODE_SELECTION,
                                    g_param_spec_boolean ("show-mode-selection", _("Show mode selection"),
-                                                        _("Show mode selection combo"), 
+                                                        _("Show mode selection combo"),
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-  g_object_class_install_property (object_class, PROP_VALID, 
+  g_object_class_install_property (object_class, PROP_VALID,
                                    g_param_spec_boolean ("valid", _("Is it a valid combination"),
-                                                        _("Is the combination of hardware and disc valid to burn the composition?"), 
+                                                        _("Is the combination of hardware and disc valid to burn the composition?"),
                                                         FALSE, G_PARAM_READABLE));
-  g_object_class_install_property (object_class, PROP_BLANK_MODE, 
+  g_object_class_install_property (object_class, PROP_BLANK_MODE,
                                    g_param_spec_boolean ("blank-mode", _("Blank mode"),
-                                                        _("The blank mode shows different disc status messages than regular mode"), 
+                                                        _("The blank mode shows different disc status messages than regular mode"),
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
+static GObject *
+xfburn_device_box_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties)
+{
+  GObject *gobj = G_OBJECT_CLASS (parent_class)->constructor(type, n_construct_properties, construct_properties);
+  XfburnDeviceBoxPrivate *priv = xfburn_device_box_get_instance_private(XFBURN_DEVICE_BOX(gobj));
+  refresh_drive_info (XFBURN_DEVICE_BOX(gobj), xfburn_device_list_get_current_device (priv->devlist));
+  return gobj;
+}
+
 static void 
 xfburn_device_box_init (XfburnDeviceBox *box)
 {
@@ -169,7 +180,7 @@ xfburn_device_box_init (XfburnDeviceBox *box)
   GtkCellRenderer *cell;
   XfburnDeviceList *devlist;
   gint n_burners;
-  
+
   gtk_orientable_set_orientation (GTK_ORIENTABLE (box), GTK_ORIENTATION_VERTICAL);
 
   priv->devlist = devlist = xfburn_device_list_new ();
@@ -179,7 +190,7 @@ xfburn_device_box_init (XfburnDeviceBox *box)
   /* devices */
   priv->combo_device = xfburn_device_list_get_device_combo (devlist);
   gtk_box_pack_start (GTK_BOX (box), priv->combo_device, FALSE, FALSE, BORDER);
-  
+
   /*
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (hbox);
@@ -255,7 +266,6 @@ xfburn_device_box_init (XfburnDeviceBox *box)
 
   priv->have_asked_for_blanking = FALSE;
 
-  refresh_drive_info (box, xfburn_device_list_get_current_device (priv->devlist));
 }
 
 static void
@@ -302,7 +312,7 @@ static void
 xfburn_device_box_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (object);
-  
+
   switch (prop_id) {
     case PROP_SHOW_WRITERS_ONLY:
       priv->show_writers_only = g_value_get_boolean (value);
@@ -340,7 +350,7 @@ empty_speed_list_dialog (void)
   dialog = (GtkDialog *) gtk_dialog_new_with_buttons (_("Empty speed list"),
                                   NULL,
                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  "window-close",
+                                  "window-close-symbolic",
                                   GTK_RESPONSE_CLOSE,
                                   NULL);
 
@@ -365,7 +375,7 @@ empty_speed_list_dialog (void)
 
   switch (gtk_dialog_run (GTK_DIALOG (dialog))) {
     case GTK_RESPONSE_CLOSE:
-      xfburn_settings_set_boolean ("show-empty-speed-list-notice", 
+      xfburn_settings_set_boolean ("show-empty-speed-list-notice",
                                    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_show_notice)));
       break;
     default:
@@ -386,15 +396,16 @@ fill_combo_speed (XfburnDeviceBox *box, XfburnDevice *device)
   int factor;
   GtkTreeIter iter_max;
 
-  if (device) {
-    g_object_get (G_OBJECT (device),
-                  "profile-no", &profile_no,
-                  "supported-speeds", &el,
-                  NULL);
-  }
-
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
+  if (device == NULL)
+    return;
+
+  g_object_get (G_OBJECT (device),
+                "profile-no", &profile_no,
+                "supported-speeds", &el,
+                NULL);
+
   if (el == NULL) {
     /* a valid disc is in the drive, but no speed list is present */
     GtkTreeIter iter;
@@ -490,14 +501,15 @@ check_disc_validity (XfburnDeviceBoxPrivate *priv)
   int profile_no = 0;
   gchar *profile_name = NULL;
   gboolean is_erasable = FALSE;
-  XfburnDevice *device = NULL;
+  XfburnDevice *device = xfburn_device_list_get_current_device (priv->devlist);
 
-  g_object_get (G_OBJECT (priv->devlist), "current-device", &device, NULL);
+  if (device == NULL) {
+    gtk_widget_set_sensitive (priv->combo_speed, FALSE);
+    priv->valid_disc = FALSE;
+    return priv->valid_disc;
+  }
 
-  if (device == NULL)
-    return FALSE;
-
-  g_object_get (G_OBJECT (device), "disc-status", &disc_status, "profile-no", &profile_no, 
+  g_object_get (G_OBJECT (device), "disc-status", &disc_status, "profile-no", &profile_no,
                                    "erasable", &is_erasable, "profile-name", &profile_name,
                                    NULL);
   if (profile_name != NULL) {
@@ -544,7 +556,7 @@ check_disc_validity (XfburnDeviceBoxPrivate *priv)
     if (!priv->valid_disc) {
         priv->status_text = _("Drive can't burn on the inserted disc");
     } else {
-      priv->valid_disc = (disc_status == BURN_DISC_BLANK); 
+      priv->valid_disc = (disc_status == BURN_DISC_BLANK);
       /* Not sure if we support appending yet, so let's disable it for the time being
        * || (disc_status == BURN_DISC_APPENDABLE); */
 
@@ -636,21 +648,21 @@ fill_combo_mode (XfburnDeviceBox *box, XfburnDevice *device)
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
   gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, _("Auto"), MODE_VALUE_COLUMN, WRITE_MODE_AUTO, -1);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, _("Automatic"), MODE_VALUE_COLUMN, WRITE_MODE_AUTO, -1);
 
-  if (device) 
+  if (device)
     g_object_get (G_OBJECT (device), "tao-block-types", &block_types, NULL);
 
   if (block_types) {
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, "TAO", MODE_VALUE_COLUMN, WRITE_MODE_TAO, -1);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, _("With Track Gaps / Track-At-Once (TAO)"), MODE_VALUE_COLUMN, WRITE_MODE_TAO, -1);
   }
 
-  if (device) 
+  if (device)
     g_object_get (G_OBJECT (device), "sao-block-types", &block_types, NULL);
   if (block_types & BURN_BLOCK_SAO) {
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, "SAO", MODE_VALUE_COLUMN, WRITE_MODE_SAO, -1);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, _("Multi Session / Session-At-Once (SAO)"), MODE_VALUE_COLUMN, WRITE_MODE_SAO, -1);
   }
   /*
    * RAW modes are not supported by libburn yet
@@ -672,7 +684,8 @@ fill_combo_mode (XfburnDeviceBox *box, XfburnDevice *device)
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, "packet", MODE_VALUE_COLUMN, WRITE_MODE_PACKET, -1);
   }
   */
-  
+
+  gtk_widget_set_sensitive (priv->combo_mode, device != NULL);
   gtk_combo_box_set_active (GTK_COMBO_BOX (priv->combo_mode), 0);
 }
 
@@ -686,12 +699,12 @@ cb_volume_change_start (XfburnDeviceList *devlist, gboolean device_changed, Xfbu
 static void
 cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, XfburnDevice *device, XfburnDeviceBox *box)
 {
+  XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
+
   g_return_if_fail (XFBURN_IS_DEVICE_LIST (devlist));
-  g_return_if_fail (XFBURN_IS_DEVICE (device));
   g_return_if_fail (XFBURN_IS_DEVICE_BOX (box));
 
-  /* FIXME: adjust selected device?  */
-
+  xfburn_device_list_refresh_device_combo (devlist, priv->combo_device);
   refresh_drive_info (box, device);
 
   if (gtk_widget_get_realized (GTK_WIDGET (box)))
@@ -700,7 +713,7 @@ cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, Xfburn
   g_signal_emit (box, signals[VOLUME_CHANGED], 0, device_changed, device);
 }
 
-static void 
+static void
 refresh_drive_info (XfburnDeviceBox *box, XfburnDevice *device)
 {
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
@@ -738,13 +751,13 @@ xfburn_device_box_new (XfburnDeviceBoxFlags flags)
 {
   GtkWidget *obj;
 
-  obj = g_object_new (xfburn_device_box_get_type (), 
-		      "show-writers-only", ((flags & SHOW_CD_WRITERS) != 0), 
-                      "show-speed-selection", ((flags & SHOW_SPEED_SELECTION) != 0), 
-		      "show-mode-selection", ((flags & SHOW_MODE_SELECTION) != 0),
-		      "blank-mode", ((flags & BLANK_MODE) != 0),
+  obj = g_object_new (xfburn_device_box_get_type (),
+                      "show-writers-only", ((flags & SHOW_CD_WRITERS) != 0),
+                      "show-speed-selection", ((flags & SHOW_SPEED_SELECTION) != 0),
+                      "show-mode-selection", ((flags & SHOW_MODE_SELECTION) != 0),
+                      "blank-mode", ((flags & BLANK_MODE) != 0),
                       NULL);
-  
+
   return obj;
 }
 
@@ -752,7 +765,7 @@ gint
 xfburn_device_box_get_speed (XfburnDeviceBox *box)
 {
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
-  
+
   GtkTreeModel *model;
   GtkTreeIter iter;
   gint speed = -1;
@@ -783,7 +796,7 @@ XfburnWriteMode
 xfburn_device_box_get_mode (XfburnDeviceBox *box)
 {
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
-  
+
   GtkTreeModel *model;
   GtkTreeIter iter;
   gint mode = -1;
