@@ -105,6 +105,7 @@ xfburn_welcome_tab_init (XfburnWelcomeTab * obj)
   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, BORDER);
   gtk_grid_set_row_spacing (GTK_GRID (table), BORDER);
   gtk_grid_set_column_spacing (GTK_GRID (table), BORDER);
+  gtk_grid_set_column_homogeneous (GTK_GRID (table), TRUE);
   gtk_widget_show (table);
 
   align = gtk_label_new (NULL);
@@ -115,7 +116,7 @@ xfburn_welcome_tab_init (XfburnWelcomeTab * obj)
   gtk_widget_show (align);
 
   /* buttons */
-  priv->button_image = create_welcome_button ("stock_xfburn", _("<big>Burn _Image</big>"), _("Burn a prepared compilation, i.e. an .ISO file"));
+  priv->button_image = create_welcome_button ("stock_xfburn", _("<big>Burn _Image</big>"), _("Burn a prepared composition, i.e. an .ISO file"));
   gtk_grid_attach (GTK_GRID (table), priv->button_image, 0, 0, 1, 1);
   gtk_widget_show (priv->button_image);
   g_signal_connect (G_OBJECT(priv->button_image), "clicked", G_CALLBACK(burn_image), obj);
@@ -162,7 +163,7 @@ create_welcome_button (const gchar *stock, const gchar *text, const gchar *secon
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 20);
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  
+
   align = gtk_label_new (NULL);
   gtk_box_pack_start (GTK_BOX (hbox), align, TRUE, TRUE, 0);
 
@@ -178,6 +179,7 @@ create_welcome_button (const gchar *stock, const gchar *text, const gchar *secon
 
   label = gtk_label_new (NULL);
   gtk_label_set_text (GTK_LABEL (label), secondary);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
   gtk_container_add (GTK_CONTAINER (button), hbox);
@@ -236,22 +238,8 @@ xfburn_welcome_tab_new (XfburnCompositionsNotebook *notebook, GActionMap *action
   obj = g_object_new (XFBURN_TYPE_WELCOME_TAB, NULL);
   if (obj) {
     XfburnWelcomeTabPrivate *priv = XFBURN_WELCOME_TAB_GET_PRIVATE (XFBURN_WELCOME_TAB(obj));
-    GAction *action;
 
     priv->notebook = notebook;
-
-    /* FIXME retrieve action group from UI Manager */
-    action = g_action_map_lookup_action (action_group, "burn-image");
-    gtk_widget_set_sensitive (priv->button_image, g_action_get_enabled (action));
-
-    action = g_action_map_lookup_action (action_group, "new-data-composition");
-    gtk_widget_set_sensitive (priv->button_data_comp, g_action_get_enabled (action));
-
-    action = g_action_map_lookup_action (action_group, "new-audio-composition");
-    gtk_widget_set_sensitive (priv->button_audio_comp, g_action_get_enabled (action));
-
-    action = g_action_map_lookup_action (action_group, "blank-disc");
-    gtk_widget_set_sensitive (priv->button_blank, g_action_get_enabled (action));
   }
 
   return obj;
